/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann           *
 *                                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef COLLATION_H_
#define COLLATION_H_
#include <QString>
#include <QList>

/**
 * \class Collation
 * \brief Data class for Collations.
 *
 * This container class stores a collation for a unicode letter.
 * The collation may have multiple weights ("levels"), that are accessible
 * with the addWeight() and getWeights() methods. Collations may also be
 * variable (isVariable(), setVariable()). The toString() method returns
 * all weights of the collation and its variable state in a string like:
 * "[*0000.0000.0000.0000]"(variable) or "[.0000.0000.0000.0000]" (not variable).
 * Objects of this class are managed in the Letter class.
 *
 * \author Martin Burgemeister <Martin.Burgemeister@gmx.de>,
 *         Mathis Lindemann <MathisLindemann@gmx.net>
 * \version 1.0
 * \date 16 August 2010
 * \see Letter
 */
class Collation
{
public:
    Collation  ();

    QString toString () const;

    void addWeight ( uint );
    QList<uint> getWeights ();

    void setVariable ( bool );
    bool isVariable  ();

    bool isEmpty () const;

private:
    /**
     * \brief The weight values of this collation.
     */
    QList<uint> weights_;
    /**
     * \brief If true, the collation is variable.
     */
    bool variable_;
};

#endif /* COLLATION_H_ */
