/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann           *
 *                                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "UCQBlockDialog.h"

/**
 * \brief Constructs the gui and sets the TableModel.
 *
 * \param parent Pointer to the parent QWidget.
 * \param tableModel TableModel in which to set the block.
 */
UCQBlockDialog::UCQBlockDialog ( QWidget* parent, TableModel* tableModel ) :
    QDialog ( parent )
{
    ui_.setupUi ( this );
    tableModel_ = tableModel;
    setAttribute ( Qt::WA_DeleteOnClose );
}

/**
 * \brief Slot for cancel button, closes the dialog, dismissing the users input.
 */
void UCQBlockDialog::on_cancelButton_clicked ()
{
    close ();
}

/**
 * \brief Slot for the OK button, adds the block to the model if all input is
 *        ok.
 *
 * The name may not be empty and the values for start and end must be valid
 * hex numbers. If one or more of the inputs is not valid a short error will
 * be displayed to allow the user to correct her input.
 */
void UCQBlockDialog::on_okButton_clicked ()
{
    ui_.errorLabel->clear ();
    QString name = ui_.nameEdit->text ().trimmed ();

    // test variables for string to number conversion
    bool testStart = false;
    bool testEnd   = false;

    // get user input for start and end
    uint start = ui_.startEdit->text ().toUInt ( &testStart, 16 );
    uint end = ui_.endEdit->text ().toUInt ( &testEnd, 16 );

    // check user input
    QString error;
    if ( name.isEmpty () )
    {
        error.append ( tr ( "Name may not be empty." ) + "\n" );
    }
    if ( !testStart )
    {
        error.append ( tr ( "Invalid start value. Please use a "
            "valid hexadecimal value." ) + "\n" );
    }
    if ( !testEnd )
    {
        error.append ( tr ( "Invalid end value. Please use a "
            "valid hexadecimal value." ) + "\n" );
    }
    if ( start > end )
    {
        error.append ( tr ( "Start must be smaller or equal to end." ) +
                       "\n" );
    }

    // if there are no errors, create the block
    if ( error.isEmpty () )
    {
        tableModel_->addBlock ( name, start, end, true );
        tableModel_->getBlockList ()->clearSelection();
        tableModel_->getBlockList ()->selectBlocks ( QStringList ( name ),
                                                     true );
        close ();
    } else
    {
        ui_.errorLabel->setText ( error );
    }
}
