/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann           *
 *                                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef UCQSTATUSBAR_H_
#define UCQSTATUSBAR_H_

#include <QStatusBar>
#include "UCQWarnings.h"
#include <QToolBar>

/**
 * \class UCQStatusBar
 * \brief Extended QStatusBar with little warnings button that can represent
 *        the existence of ne warnings in a UCQWarnings.
 *
 * \author Martin Burgemeister <Martin.Burgemeister@gmx.de>,
 *         Mathis Lindemann <MathisLindemann@gmx.net>
 * \version 1.0
 * \date 16 August 2010
 * \see UCQWarnings
 */
class UCQStatusBar: public QStatusBar
{

Q_OBJECT

public:
    UCQStatusBar  ( QWidget*, UCQWarnings* );
    ~UCQStatusBar ();

private:
    /**
     * \brief The warnings dialog to use.
     */
    UCQWarnings* warningsDialog_;
    /**
     * \brief Toolbar to put the action in.
     */
    QToolBar* warningsBox_;
    /**
     * \brief Action for opening the warningsDialog_.
     */
    QAction* warningsAction_;
    /**
     * \brief Icon for active state of the action ( new warnings available ).
     */
    QIcon* warningsIcon_;
    /**
     * \brief Icon for the deactivated state of the action ( no new warnings ).
     */
    QIcon* warningsIconDeactivated_;

public slots:
    void newWarnings ();

protected slots:
    void on_warningsAction_triggered ();
};

#endif /* UCQSTATUSBAR_H_ */
