/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann		   *
 *      																   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef UCQEXECUTELUATHREAD_H_
#define UCQEXECUTELUATHREAD_H_
#include <QThread>
#include "controller/LuaController.h"
/**
 * \class UCQExecuteLuaThread
 * \brief Thread for the Lua  execution.
 *
 * This class creates a new thread for the execution of a lua command or file.
 *
 * \author Martin Burgemeister <Martin.Burgemeister@gmx.de>,
 *         Mathis Lindemann <MathisLindemann@gmx.net>
 * \version 1.0
 * \date 16 August 2010
 * \see LuaController
 */
class UCQExecuteLuaThread: public QThread {
Q_OBJECT
public:
	enum executionMode {
		EXECUTE_FILE = 0x0, EXECUTE_STRING = 0x1
	};
	Q_DECLARE_FLAGS(ExecutionMode, executionMode)

	UCQExecuteLuaThread(LuaController *, ExecutionMode = EXECUTE_STRING);

	void setexecutionMode(ExecutionMode exeMode);
	void setLuaController(LuaController *);
	void execute(QString execute);
	void run();

private:
	/**
	 * \brief The LuaController for execution.
	 */
	LuaController * lua_;
	/**
	 * \brief The file to execute.
	 */
	QString execute_;

	/**
	 * \brief Execution Mode
	 */
	ExecutionMode executionMode_;
signals:
	/**
	 * \brief Sends the running signals.
	 *
	 * true If the lua command starts.
	 * false If the lua command ends.
	 *
	 * \param bool Is the Thread running.
	 */
	void running(bool);
};
Q_DECLARE_OPERATORS_FOR_FLAGS(UCQExecuteLuaThread::ExecutionMode)
#endif /* UCQEXECUTELUATHREAD_H_ */
